Mixor-package: Mixed-Effects Ordinal Regression Analysis

mixor-packageR Documentation

Mixed-Effects Ordinal Regression Analysis

Description

This package provides a function mixor for fitting mixed-effects ordinal and binary response models and associated methods for printing, summarizing, extracting estimated coefficients and the variance-covariance matrix, and estimating contrasts for the fitted models.

Details

This package was not yet installed at build time.
Index: This package was not yet installed at build time.
This package provides a function mixor for fitting mixed-effects ordinal and binary response models and associated methods for printing, summarizing, extracting estimated coefficients and the variance-covariance matrix, and estimating contrasts for the fitted models.

Author(s)

Kellie J. Archer [aut, cre] (ORCID: <https://orcid.org/0000-0003-1555-5781>), Donald Hedeker [aut], Rachel Nordgren [aut], Robert D. Gibbons [aut] Kellie J. Archer, Donald Hedeker, Rachel Nordgren, Robert D. Gibbons Maintainer: Kellie J. Archer <archer.43@osu.edu> Kellie J. Archer <archer.43@osu.edu>

References

Hedeker D. and Gibbons R.D. (1996) A computer program for mixed-effects ordinal regression analysis. Computer Methods and Programs in Biomedicine 49, 157-176.

See Also

See also mixor, and examples in norcag, irt.data, concen, SmokeOnset, schizophrenia

Examples

library("mixor")
data("SmokingPrevention")
# data frame must be sorted by id variable
SmokingPrevention<-SmokingPrevention[order(SmokingPrevention$class),]
# school model
Fitted.school<-mixor(thksord~thkspre+cc+tv+cctv, data=SmokingPrevention, 
   id=school, link="logit")
summary(Fitted.school)
vcov(Fitted.school)
# students in classrooms analysis 
Fitted.students<-mixor(thksord~thkspre+cc+tv+cctv, data=SmokingPrevention, 
   id=class, link="logit", nAGQ=11)
summary(Fitted.students)
coef(Fitted.students)
vcov(Fitted.students)
cm<-matrix(c(-1,-1,-1,0,0,0,0,0,                                             
		0,0,0,0,0,0,0,0,
		0,0,0,1,0,0,0,1),
		ncol=3,byrow=TRUE)
Contrasts(Fitted.students, contrast.matrix=cm)

mixor documentation built on July 3, 2026, 9:07 a.m.