| coef.mixor | R Documentation |
coef.mixor is a generic function which extracts the model coefficients from a fitted model object fit using mixor
## S3 method for class 'mixor'
coef(object, ...)
object |
a |
... |
other arguments. |
Coefficients extracted from the model object.
Kellie J. Archer, Donald Hedeker, Rachel Nordgren, Robert D. Gibbons
See Also as mixor, summary.mixor
library("mixor")
data("schizophrenia")
### Random intercept model
SCHIZO1.fit<-mixor(imps79o ~ TxDrug + SqrtWeek + TxSWeek, data=schizophrenia,
id=id, link="probit")
coef(SCHIZO1.fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.