| plot.mixor | R Documentation |
Plot of empirical Bayes estimates of random effects from a fitted mixor model object.
## S3 method for class 'mixor'
plot(x, ...)
x |
a |
... |
other arguments. |
For each random effect, a histogram and normal quantile-quantile plot of empirical Bayes estimates.
Kellie J. Archer, Donald Hedeker, Rachel Nordgren, Robert D. Gibbons
See Also as mixor, summary.mixor
library("mixor")
data("schizophrenia")
### Random intercept
SCHIZO1.fit<-mixor(imps79o ~ TxDrug + SqrtWeek + TxSWeek, data=schizophrenia,
id=id, link="probit")
plot(SCHIZO1.fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.