| print.mixor | R Documentation |
print method for class mixor.
## S3 method for class 'mixor'
print(x, digits = max(3L, getOption("digits") - 3L), ...)
x |
an object of class |
digits |
the number of significant digits to use when printing. |
... |
further arguments passed to or from other methods. |
The function print.mixor prints the model call and coefficients from the mixor object.
Kellie J. Archer, Donald Hedeker, Rachel Nordgren, Robert D. Gibbons
See Also as mixor, summary.mixor, coef.mixor
library("mixor")
data("schizophrenia")
### Random intercept
SCHIZO1.fit<-mixor(imps79o ~ TxDrug + SqrtWeek + TxSWeek, data=schizophrenia,
id=id, link="probit")
print(SCHIZO1.fit)
### Random intercept and slope
SCHIZO2.fit<-mixor(imps79o ~ TxDrug + SqrtWeek + TxSWeek, data=schizophrenia,
id=id, which.random.slope=2, link="probit")
print(SCHIZO2.fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.