| schizophrenia | R Documentation |
In the NIMH Schizophrenia Collaborative Study, patients were randomized to receive one of four medications, either placebo or one of three different anti-psychotic drugs. The protocol indicated subjects were to then be evaluated at weeks 0, 1, 3, 6 to assess severity of illness; additionally some measurements were made at weeks 2, 4, and 5.
data(schizophrenia)
A data frame with 1603 observations on the following 9 variables.
ida numeric vector indicating the unique patient identifier
imps79a numeric vector from item 79 on the Inpatient Multidimensional Psychiatric Scale indicating severity of illness. The scores were applied to be interpreted as follows: 1 = normal, not ill at all; 2 = borderline mentally ill; 3 = mildly ill; 4 = moderately ill; 5 = markedly ill; 6 = severly ill; 7 = among the most extremely ill
imps79ba binary version of imps79
imps79oan ordinally scaled version of imps79
inta numeric vector of ones; used in stand-alone package to indicate intercept
TxDruga numeric vector indicating treatment with drug (1) or placebo (0)
Weeka numeric vector indicating time, in weeks
SqrtWeekthe square root of the Week variable
TxSWeeka variable representing the TxDrug x Week interaction
From https://voices.uchicago.edu/hedeker/files/2026/06/SCHIZX1.DAT_.txt
Hedeker D. and Gibbons R.D. (1996) A computer program for mixed-effects ordinal regression analysis. Computer Methods and Programs in Biomedicine 49, 157-176. Hedeker D and Gibbons R.D. (2006) Longitudinal Data Analysis, Wiley, Hoboken, New Jesery.
library("mixor")
data("schizophrenia")
### Random intercept
SCHIZO1.fit<-mixor(imps79o ~ TxDrug + SqrtWeek + TxSWeek, data=schizophrenia,
id=id, link="probit")
summary(SCHIZO1.fit)
### Random intercept and slope
SCHIZO2.fit<-mixor(imps79o ~ TxDrug + SqrtWeek + TxSWeek, data=schizophrenia,
id=id, which.random.slope=2, link="probit")
summary(SCHIZO2.fit)
# random intercept and trend with independent random effects; using logit link
SCHIZO3.fit<-mixor(imps79o ~ TxDrug + SqrtWeek + TxSWeek, data=schizophrenia,
id=id, which.random.slope=2, indep.re=TRUE, link="logit")
summary(SCHIZO3.fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.