View source: R/summary.mixor.R
| summary.mixor | R Documentation |
summary method for class mixor.
## S3 method for class 'mixor'
summary(object, digits=max(3, getOption("digits") - 2),
signif.stars=TRUE, dig.tst = max(1, min(5, digits - 1)), ...)
object |
an object of class |
digits |
minimum number of significant digits to be used for most numbers. |
signif.stars |
logical; if TRUE, P-values are additionally encoded visually as "significance stars" in order to help scanning of long coefficient tables. |
dig.tst |
minimum number of significant digits for the test statistics. |
... |
other arguments. |
Prints the following items extracted from the fitted mixor object:
the call to mixor (model formula), mode Deviance, Log-likelihood, RIDGEMAX, AIC, SBC, and model paramter estimates along with their SE, Z, and p-value.
Kellie J. Archer, Donald Hedeker, Rachel Nordgren, Robert D. Gibbons
See Also mixor, print.mixor, coef.mixor
library("mixor")
data("schizophrenia")
### Random intercept
SCHIZO1.fit<-mixor(imps79o ~ TxDrug + SqrtWeek + TxSWeek, data=schizophrenia,
id=id, link="probit")
summary(SCHIZO1.fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.